==> react-native-0.0.0-20211206-2012-66243271a.tgz: package/ReactAndroid/src/test/java/com/facebook/react/modules/clipboard/ClipboardModuleTest.java <==
/*
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

package com.facebook.react.modules.clipboard;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import android.annotation.SuppressLint;
import android.content.Context;
import android.text.ClipboardManager;
import com.facebook.react.bridge.ReactApplicationContext;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.powermock.core.classloader.annotations.PowerMockIgnore;
import org.robolectric.RobolectricTestRunner;
import org.robolectric.RuntimeEnvironment;

@SuppressLint({"ClipboardManager", "DeprecatedClass"})
@RunWith(RobolectricTestRunner.class)
@PowerMockIgnore({"org.mockito.*", "org.robolectric.*", "androidx.*", "android.*"})
public class ClipboardModuleTest {

  private static final String TEST_CONTENT = "test";

  private ClipboardModule mClipboardModule;
  private ClipboardManager mClipboardManager;

  @Before
  public void setUp() {
    mClipboardModule =
        new ClipboardModule(new ReactApplicationContext(RuntimeEnvironment.application));
    mClipboardManager =
        (ClipboardManager)
            RuntimeEnvironment.application.getSystemService(Context.CLIPBOARD_SERVICE);
  }

  @Test
  public void testSetString() {
    mClipboardModule.setString(TEST_CONTENT);
    assertTrue(mClipboardManager.getText().equals(TEST_CONTENT));

    mClipboardModule.setString(null);
    assertFalse(mClipboardManager.hasText());

    mClipboardModule.setString("");
    assertFalse(mClipboardManager.hasText());

    mClipboardModule.setString(" ");
    assertTrue(mClipboardManager.hasText());
  }
}

==> react-native-0.23.1.tgz: package/ReactAndroid/src/test/java/com/facebook/react/modules/clipboard/ClipboardModuleTest.java <==
/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 */

package com.facebook.react.modules.clipboard;

import android.annotation.SuppressLint;
import android.content.Context;
import android.text.ClipboardManager;

import com.facebook.react.bridge.ReactTestHelper;
import com.facebook.react.modules.clipboard.ClipboardModule;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.powermock.core.classloader.annotations.PowerMockIgnore;
import org.robolectric.Robolectric;
import org.robolectric.RobolectricTestRunner;
import org.robolectric.RuntimeEnvironment;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.assertFalse;

@SuppressLint({"ClipboardManager", "DeprecatedClass"})
@RunWith(RobolectricTestRunner.class)
@PowerMockIgnore({"org.mockito.*", "org.robolectric.*", "android.*"})
public class ClipboardModuleTest {

  private static final String TEST_CONTENT = "test";

  private ClipboardModule mClipboardModule;
  private ClipboardManager mClipboardManager;

  @Before
  public void setUp() {
    mClipboardModule = new ClipboardModule(ReactTestHelper.createCatalystContextForTest());
    mClipboardManager =
        (ClipboardManager) RuntimeEnvironment.application.getSystemService(Context.CLIPBOARD_SERVICE);
  }

  @Test
  public void testSetString() {
    mClipboardModule.setString(TEST_CONTENT);
    assertTrue(mClipboardManager.getText().equals(TEST_CONTENT));

    mClipboardModule.setString(null);
    assertFalse(mClipboardManager.hasText());

    mClipboardModule.setString("");
    assertFalse(mClipboardManager.hasText());

    mClipboardModule.setString(" ");
    assertTrue(mClipboardManager.hasText());
  }
}
